<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="tr">
<context>
    <name>AptConfigMessage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="83"/>
        <source>Enter the number to configure: </source>
        <translation>Yapılandırılacak numarayı gir:</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/AptConfigMessage.cpp" line="88"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>BackendProcessPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="16"/>
        <source>Loading packages...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="17"/>
        <source>%1/%2 loaded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/backendprocesspage.cpp" line="20"/>
        <source>Initializing...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DdimErrorPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/ddimerrorpage.cpp" line="17"/>
        <source>OK</source>
        <translation>Tamam</translation>
    </message>
</context>
<context>
    <name>DebInstaller</name>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="101"/>
        <source>Package Installer</source>
        <translation>Paket Kurucu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="109"/>
        <source>Settings</source>
        <translation>Ayarlar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="130"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="537"/>
        <source>Installing other packages... Please open it later.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="541"/>
        <source>Parsing failed: An illegal file structure was found in the manifest file!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="543"/>
        <source>Parsing failed: An illegal version number was found in the manifest file!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="545"/>
        <source>No deb packages found. Please check the folder.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="631"/>
        <source>The deb package may be broken</source>
        <translation>Deb paketi bozulmuş olabilir</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="639"/>
        <source>You can only install local deb packages</source>
        <translation>Yalnızca diskteki deb paketlerini kurabilirsiniz</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="653"/>
        <source>Already Added</source>
        <translation>Zaten Eklenmiş</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="662"/>
        <source>%1 does not exist, please reselect</source>
        <translation>%1 mevcut değil, lütfen yeniden seçin</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="330"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="669"/>
        <location filename="../src/deb-installer/view/pages/debinstaller.cpp" line="799"/>
        <source>Bulk Install</source>
        <translation>Toplu Kurulum</translation>
    </message>
</context>
<context>
    <name>DebListModel</name>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="87"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="104"/>
        <source>Installation failed, please check your network connection</source>
        <translation>Kurulum tamamlanamadı, lütfen ağ bağlantınızı denetleyin</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="89"/>
        <source>Installation failed, please check for updates in Control Center</source>
        <translation>Kurulum başarısız, lütfen Kontrol Merkezindeki güncellemeleri kontrol edin</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="92"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="96"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="108"/>
        <source>Installation failed, insufficient disk space</source>
        <translation>Kurulum tamamlanamadı, disk alanı yetersiz</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="113"/>
        <source>No digital signature</source>
        <translation>Dijital imza yok</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="117"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="621"/>
        <source>Invalid digital signature</source>
        <translation>Geçersiz dijital imza</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="124"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="614"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1564"/>
        <source>The administrator has set policies to prevent installation of this package</source>
        <translation>Yönetici, bu paketin yüklenmesini önlemek için politikalar belirledi</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="129"/>
        <source>Installation Failed</source>
        <translation>Kurulum tamamlanamadı</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="623"/>
        <source>Failed to install %1</source>
        <translation>%1 Kurulamadı</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="911"/>
        <source>Failed to install %1: no valid digital singature</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="949"/>
        <source>Unable to install - no digital signature</source>
        <translation>Yüklenemiyor - dijital imza yok</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="950"/>
        <source>Please go to Control Center to enable developer mode and try again. Proceed?</source>
        <translation>Geliştirici kipini etkinleştirmek için lütfen Kontrol Merkezi&apos;ne gidin ve tekrar deneyin. İlerle?</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="953"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="954"/>
        <source>Proceed</source>
        <comment>button</comment>
        <translation>İlerle</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="907"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1009"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1566"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1047"/>
        <source>This package does not have a valid digital signature. Continue with the installation?</source>
        <translation>Bu paketin geçerli bir dijital imzası yok. Kuruluma devam edilsin mi? </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1049"/>
        <source>Cancel</source>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1050"/>
        <source>Continue</source>
        <comment>button</comment>
        <translation>Devam et</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="905"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1006"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1563"/>
        <source>Unable to install</source>
        <translation>Kurulamıyor</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="1007"/>
        <source>This package does not have a valid digital signature</source>
        <translation>Bu paketin geçerli bir dijital imzası yok</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="626"/>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="631"/>
        <source>Broken dependencies: %1</source>
        <translation>Bozuk bağımlılıklar: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="121"/>
        <source>Authentication failed</source>
        <translation>Kimlik doğrulama başarısız</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/deblistmodel.cpp" line="612"/>
        <source>Unmatched package architecture</source>
        <translation>Paket mimarisi uyumsuz</translation>
    </message>
</context>
<context>
    <name>FileChooseWidget</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="60"/>
        <source>Drag deb packages here</source>
        <translation>Deb paketlerini buraya sürükle</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/filechoosewidget.cpp" line="102"/>
        <source>Select File</source>
        <translation>Dosya Seç</translation>
    </message>
</context>
<context>
    <name>MultipleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Show details</source>
        <translation>Ayrıntıları göster</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="33"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Daralt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="171"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Kur</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="172"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="174"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="468"/>
        <source>Dependencies in the repository</source>
        <translation>Depodaki bağımlılıklar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="474"/>
        <source>Missing dependencies</source>
        <translation>Eksik bağımlılıklar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="523"/>
        <source>Installing dependencies: %1</source>
        <translation>Bağımlılıklar kuruluyor: %1</translation>
    </message>
</context>
<context>
    <name>PackageSelectItem</name>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="82"/>
        <source>Same version installed</source>
        <translation>Aynı sürüm kurulu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="85"/>
        <source>Earlier version installed: %1</source>
        <translation>Önceki sürüm kurulu: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="89"/>
        <source>Later version installed: %1</source>
        <translation>Daha sonraki sürüm kurulu: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/widgets/packageselectitem.cpp" line="94"/>
        <source>Unmatched package architecture</source>
        <translation>Paket mimarisi uyumsuz</translation>
    </message>
</context>
<context>
    <name>PackageSelectView</name>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="19"/>
        <source>Select all</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/packageselectview.cpp" line="20"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Kur</translation>
    </message>
</context>
<context>
    <name>PackagesListDelegate</name>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="60"/>
        <source>Installing</source>
        <translation>Kuruluyor</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="64"/>
        <source>Installed</source>
        <translation>Kuruldu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="72"/>
        <source>Failed</source>
        <translation>Başarısız</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="68"/>
        <source>Waiting</source>
        <translation>Bekleniyor</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="231"/>
        <source>Same version installed</source>
        <translation>Aynı sürüm kurulu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="234"/>
        <source>Later version installed: %1</source>
        <translation>Daha sonraki sürüm kurulu: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/model/packageslistdelegate.cpp" line="237"/>
        <source>Earlier version installed: %1</source>
        <translation>Önceki sürüm kurulu: %1</translation>
    </message>
</context>
<context>
    <name>PackagesListView</name>
    <message>
        <location filename="../src/deb-installer/model/packagelistview.cpp" line="160"/>
        <source>Delete</source>
        <translation>Sil</translation>
    </message>
</context>
<context>
    <name>QApplication</name>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Daralt</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="9"/>
        <source>Basic</source>
        <translation>Temel</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/setting_translation.cpp" line="10"/>
        <source>Check digital signatures if the developer mode is enabled</source>
        <translation>Geliştirici modu etkinse dijital imzaları kontrol edin</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="707"/>
        <source>Collapse</source>
        <translation>Daralt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="333"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="803"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="966"/>
        <source>Reinstall</source>
        <translation>Yeniden kur</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="806"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="969"/>
        <source>Later version installed: %1</source>
        <translation>Daha sonraki sürüm kurulu: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="808"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="971"/>
        <source>Downgrade</source>
        <translation>Düşür</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="811"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="974"/>
        <source>Earlier version installed: %1</source>
        <translation>Önceki sürüm kurulu: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="876"/>
        <source>Installing dependencies: %1</source>
        <translation>Bağımlılıklar kuruluyor: %1</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1011"/>
        <source>Failed to install %1</source>
        <translation>%1 Kurulamadı</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="178"/>
        <source>Version: </source>
        <translation>Sürüm: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="325"/>
        <source>Install</source>
        <comment>button</comment>
        <translation>Kur</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="329"/>
        <source>Remove</source>
        <comment>button</comment>
        <translation>Kaldır</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="337"/>
        <source>OK</source>
        <comment>button</comment>
        <translation>Tamam</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="341"/>
        <source>Back</source>
        <comment>button</comment>
        <translation>Geri</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="345"/>
        <source>Done</source>
        <comment>button</comment>
        <translation>Bitti</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="679"/>
        <source>Installed successfully</source>
        <translation>Kuruldu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="684"/>
        <source>Uninstalled successfully</source>
        <translation>Kaldırıldı</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="698"/>
        <source>Uninstall Failed</source>
        <translation>Kaldırılamadı</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="727"/>
        <source>Dependencies in the repository</source>
        <translation>Depodaki bağımlılıklar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="733"/>
        <source>Missing dependencies</source>
        <translation>Eksik bağımlılıklar</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="813"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="976"/>
        <source>Update</source>
        <comment>button</comment>
        <translation>Yükselt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="1016"/>
        <source>Invalid digital signature</source>
        <translation>Geçersiz dijital imza</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="166"/>
        <source>Name: </source>
        <translation>Ad: </translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="802"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="965"/>
        <source>Same version installed</source>
        <translation>Aynı sürüm kurulu</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Install</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="45"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="526"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="551"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="678"/>
        <source>Show details</source>
        <translation>Ayrıntıları göster</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/multipleinstallpage.cpp" line="30"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="46"/>
        <source>Show dependencies</source>
        <translation>Bağımlılıkları göster</translation>
    </message>
</context>
<context>
    <name>SingleInstallPage_Uninstall</name>
    <message>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="576"/>
        <location filename="../src/deb-installer/view/pages/singleinstallpage.cpp" line="683"/>
        <source>Show details</source>
        <translation>Ayrıntıları göster</translation>
    </message>
</context>
<context>
    <name>UninstallConfirmPage</name>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Show related packages</source>
        <translation>İlgili paketleri göster</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="16"/>
        <source>Collapse</source>
        <comment>button</comment>
        <translation>Daralt</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="37"/>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>İptal</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="39"/>
        <source>Confirm</source>
        <translation>Onayla</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="112"/>
        <source>Are you sure you want to uninstall %1?
All dependencies will also be removed</source>
        <translation>%1 uygulamasını kaldırmak istediğinize emin misiniz?
Tüm bağımlılıklar da kaldırılacak</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/view/pages/uninstallconfirmpage.cpp" line="114"/>
        <source>Are you sure you want to uninstall %1?
The system or other applications may not work properly</source>
        <translation>%1 uygulamasını kaldırmak istediğinizden emin misiniz?
Sistem veya diğer uygulamalar düzgün çalışmayabilir</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="48"/>
        <location filename="../src/deb-installer/main.cpp" line="49"/>
        <source>Package Installer</source>
        <translation>Paket Kurucu</translation>
    </message>
    <message>
        <location filename="../src/deb-installer/main.cpp" line="50"/>
        <source>Package Installer helps users install and remove local packages, and supports bulk installation.</source>
        <translation>Paket Kurucu, kullanıcıların yerel paketleri kurmasına ve kaldırmasına yardımcı olur ve toplu kurulumu destekler.</translation>
    </message>
</context>
</TS>